==> pointpos_api-0.0.5.tar.gz: doc/DiscountApi.md <==
# pointpos_api.api.DiscountApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createDiscount**](DiscountApi.md#createDiscount) | **POST** /discount | Create Discount
[**deleteDiscountByID**](DiscountApi.md#deleteDiscountByID) | **DELETE** /discount/{id} | Delete Discount By ID
[**findDiscount**](DiscountApi.md#findDiscount) | **GET** /discount | Get Discount List
[**getDiscountByID**](DiscountApi.md#getDiscountByID) | **GET** /discount/{id} | Get Discount By ID
[**updateDiscountByID**](DiscountApi.md#updateDiscountByID) | **PUT** /discount/{id} | Update Discount By ID


# **createDiscount**
> Discount createDiscount(authorization, xAPIKey, body)

Create Discount

Create Discount

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = Discount(); // Discount | 

try { 
    var result = api_instance.createDiscount(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling DiscountApi->createDiscount: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**Discount**](Discount.md)|  | 

### Return type

[**Discount**](Discount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteDiscountByID**
> deleteDiscountByID(authorization, xAPIKey, id)

Delete Discount By ID

Delete Discount By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 

try { 
    api_instance.deleteDiscountByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling DiscountApi->deleteDiscountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findDiscount**
> List<Discount> findDiscount(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Discount List

Get Discount  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"   - \"amount\"   - \"isPercentage\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findDiscount(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling DiscountApi->findDiscount: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;   - \&quot;amount\&quot;   - \&quot;isPercentage\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to []]

### Return type

[**List<Discount>**](Discount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getDiscountByID**
> Discount getDiscountByID(authorization, xAPIKey, id)

Get Discount By ID

Get Discount By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 

try { 
    var result = api_instance.getDiscountByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling DiscountApi->getDiscountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]

### Return type

[**Discount**](Discount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateDiscountByID**
> Discount updateDiscountByID(authorization, xAPIKey, id, body)

Update Discount By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = Discount(); // Discount | 

try { 
    var result = api_instance.updateDiscountByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling DiscountApi->updateDiscountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**Discount**](Discount.md)|  | 

### Return type

[**Discount**](Discount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.0.13.tar.gz: doc/DiscountApi.md <==
# pointpos_api.api.DiscountApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createDiscount**](DiscountApi.md#createDiscount) | **Post** /discount | Create Discount
[**deleteDiscountByID**](DiscountApi.md#deleteDiscountByID) | **Delete** /discount/:id | Delete Discount By ID
[**findDiscount**](DiscountApi.md#findDiscount) | **Get** /discount | Get Discount List
[**getDiscountByID**](DiscountApi.md#getDiscountByID) | **Get** /discount/:id | Get Discount By ID
[**updateDiscountByID**](DiscountApi.md#updateDiscountByID) | **Put** /discount/:id | Update Discount By ID


# **createDiscount**
> Discount createDiscount(authorization, xAPIKey, body)

Create Discount

Create Discount

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new Discount(); // Discount | 

try { 
    var result = api_instance.createDiscount(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling DiscountApi->createDiscount: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**Discount**](Discount.md)|  | 

### Return type

[**Discount**](Discount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteDiscountByID**
> deleteDiscountByID(authorization, xAPIKey, id)

Delete Discount By ID

Delete Discount By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 

try { 
    api_instance.deleteDiscountByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling DiscountApi->deleteDiscountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findDiscount**
> List<Discount> findDiscount(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Discount List

Get Discount  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"   - \"amount\"   - \"isPercentage\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findDiscount(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling DiscountApi->findDiscount: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;   - \&quot;amount\&quot;   - \&quot;isPercentage\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]

### Return type

[**List<Discount>**](Discount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getDiscountByID**
> Discount getDiscountByID(authorization, xAPIKey, id)

Get Discount By ID

Get Discount By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 

try { 
    var result = api_instance.getDiscountByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling DiscountApi->getDiscountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]

### Return type

[**Discount**](Discount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateDiscountByID**
> Discount updateDiscountByID(authorization, xAPIKey, id, body)

Update Discount By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new DiscountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new Discount(); // Discount | 

try { 
    var result = api_instance.updateDiscountByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling DiscountApi->updateDiscountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**Discount**](Discount.md)|  | 

### Return type

[**Discount**](Discount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
